"""
Script to convert yolov4.weights file from AlexeyAB/darknet to tensorflow weights.

Initial implementation comes from https://github.com/zzh8829/yolov3-tf2
"""

import numpy as np

from .anchors import YOLOV4_ANCHORS
from .model import YOLOv4
from .weights import load_darknet_weights_in_yolo


def convert_darknet_weights(darknet_weights_path,
                            output_weights_path,
                            input_shape,
                            num_classes,
                            weights="darknet"):
    """ Converts yolov4 darknet weights to tensorflow weights (.h5 file)

    Args:
        darknet_weights_path (str): Input darknet weights filepath (*.weights).
        output_weights_path (str): Output tensorflow weights filepath (*.h5).
        num_classes (int): Number of output classes
    """
    model = YOLOv4(input_shape=input_shape,
                   num_classes=num_classes,
                   anchors=YOLOV4_ANCHORS,
                   weights=weights)
    # pylint: disable=E1101
    model.predict(np.random.random((1, *input_shape)))

    model = load_darknet_weights_in_yolo(model, darknet_weights_path)

    model.save(output_weights_path)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="FQCS",
    version="1.1.2",
    author="FQCS Team",
    author_email="trannamtrung1st@gmail.com",
    description="This is for FQCS Capstone Project",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/trannamtrung1st/FQCS-Research",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'numpy', 'imutils', 'opencv-python', 'scipy', 'tensorflow',
        'tensorflow-addons'
    ],
    python_requires='>=3.5',
)



import requests
from .fqcs_constants import ISO_DATE_FORMAT, SERVER_ISO_DATE_FORMAT
import datetime


def refresh_token(api_url, r_token, headers=None):
    try:
        form_data = {}
        form_data['grant_type'] = 'refresh_token'
        form_data['refresh_token'] = r_token
        url = "{}/api/users/login".format(api_url)
        resp = requests.post(url, data=form_data, headers=headers)
        if (resp.status_code >= 200 and resp.status_code < 300):
            data = resp.json()
            return (True, data)
        else:
            return (False, resp)
    except Exception as ex:
        return (None, ex)


def login(api_url, username, password, headers=None):
    try:
        form_data = {}
        form_data['username'] = username
        form_data['password'] = password
        url = "{}/api/users/login".format(api_url)
        resp = requests.post(url, data=form_data, headers=headers)
        if (resp.status_code >= 200 and resp.status_code < 300):
            data = resp.json()
            return (True, data)
        else:
            return (False, resp)
    except Exception as ex:
        return (None, ex)


def count_events(api_url, query_obj=None, headers=None):
    try:
        url = "{}/api/qc-events/count".format(api_url)
        resp = requests.get(url, query_obj, headers=headers)
        if (resp.status_code >= 200 and resp.status_code < 300):
            data = resp.json()
            return (True, data)
        else:
            return (False, resp)
    except Exception as ex:
        return (None, ex)


def submit_event(api_url, defect_type, left_img, right_img, headers=None):
    try:
        data = {}
        data['defect_type_code'] = defect_type
        data['left_image'] = left_img
        data['right_image'] = right_img
        data['date_format'] = SERVER_ISO_DATE_FORMAT
        utc_now = datetime.datetime.utcnow()
        utc_str = utc_now.strftime(ISO_DATE_FORMAT)
        data['created_time_str'] = utc_str
        url = "{}/api/qc-events".format(api_url)
        resp = requests.post(url, json=data, headers=headers)
        if (resp.status_code >= 200 and resp.status_code < 300):
            data = resp.json()
            return (True, data)
        else:
            return (False, resp)
    except Exception as ex:
        return (None, ex)


def get_common_headers(auth_token=None):
    return {"Authorization": f"Bearer {auth_token}"}
